@@ -8,7 +8,7 @@ font_file = '/home/apyb/verdana.ttf'
 
 def generate(name, role):
 
-    img = Image.open(cert)
+    img = Image.open(cert_file)
     draw = ImageDraw.Draw(img)
 
     font = ImageFont.truetype(font_file, 128)
